<?php

namespace App\Jobs;

use App\Command\Log;
use App\Models\OrderDivideRecord;
use App\Models\Service;
use App\Models\StoreInfo;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldBeUnique;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Facades\DB;

class AutoCompleteOrder implements ShouldQueue
{
    use Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

    protected $order;
    /**
     * Create a new job instance.
     *
     * @return void
     */
    public function __construct($order, $delay)
    {
        $this->order = $order;
        // 设置延迟的时间，delay() 方法的参数代表多少秒之后执行
        $this->delay($delay);
    }

    /**
     * * 定义这个任务类具体的执行逻辑
     * 当队列处理器从队列中取出任务时，会调用 handle() 方法
     * Execute the job.
     *
     * @return void
     */
    public function handle()
    {
        if ($this->order->order_status != 3) { //待评价
            return;
        }
        // 通过事务执行 sql
        DB::beginTransaction();
        try {
            $this->order->order_status = 4; //已完成
            $this->order->save();
            //佣金分配
            OrderDivideRecord::divide($this->order->id);
            // switch ($this->order->business_id) {
            //     case 0:
            //         $this->order->store_order->status = 2;
            //         $this->order->store_order->over_time = date('Y-m-d H:i:s');
            //         $this->order->store_order->save();
            //         $store = StoreInfo::where(['store_id' => $this->order->store_order->store_id])->first();
            //         $store->total_revenue += $this->order->pay_money;
            //         $store->balance += $this->order->pay_money;
            //         $store->save();
            //         dispatch(new AutoCommentOrder($this->order, (3 * 24 * 3600)));
            //         break;
            //     case 1:
            //     case 2:
            //     case 3:
            //     case 4:
            //     case 5:
            //         $fcbl = Service::find($this->order->service_id)->fenmo ?? 0;
            //         //订单佣金分配
            //         Employee::divide($this->order->id, $this->order->em_id, $this->order->pay_money, $fcbl);
            //         dispatch(new AutoCommentOrder($this->order, (3 * 24 * 3600)));
            //         break;
            //     default:
            //         break;
            // }

            DB::commit();
            //dispatch(new AutoCommentOrder($this->order, (3 * 24 * 3600)));
            Log::add('订单自动完成', $this->order->toArray());
        } catch (\Exception $exception) {
            DB::rollBack();
            Log::add('自动完成订单失败', $exception);
        }
    }
}
